@@ -105,7 +105,7 @@ KGravitySetup::~KGravitySetup()
 // read settings from config file
 void KGravitySetup::readSettings()
 {
-	KConfig config("kssgravityrc", KConfig::NoGlobals);
+	KConfig config(QLatin1String( "kssgravityrc" ), KConfig::NoGlobals);
         KConfigGroup grp = config.group( "Settings" );
 
 	bool boolval = grp.readEntry( "Stars", false );
@@ -123,7 +123,7 @@ void KGravitySetup::readSettings()
 // Ok pressed - save settings and exit
 void KGravitySetup::slotOkPressed()
 {
-	KConfig _config("kssgravityrc", KConfig::NoGlobals);
+	KConfig _config(QLatin1String( "kssgravityrc" ), KConfig::NoGlobals);
 	KConfigGroup config(&_config, "Settings" );
 
 	if (cfg->RadioButton1->isChecked())
@@ -203,7 +203,7 @@ Gravity::Gravity( QWidget * parent ) : QGLWidget (parent)
 //	obj = gluNewQuadric();
 
 // This has to be here because you can't update the gravity until 'gravity' is created!
-	KConfig _config("kssgravityrc", KConfig::NoGlobals);
+	KConfig _config(QLatin1String( "kssgravityrc" ), KConfig::NoGlobals);
 	KConfigGroup config(&_config, "Settings" );
 	bool boolval = config.readEntry( "Stars", false );
         setStars(boolval);
@@ -226,8 +226,8 @@ bool Gravity::loadParticle()
     bool Status = true;
     QImage buf;
 
-    kDebug() << "Loading: " << KStandardDirs::locate("data", "kscreensaver/particle.png");
- if (buf.load( KStandardDirs::locate("data", "kscreensaver/particle.png") ) )
+    kDebug() << "Loading: " << KStandardDirs::locate("data", QLatin1String( "kscreensaver/particle.png" ));
+ if (buf.load( KStandardDirs::locate("data", QLatin1String( "kscreensaver/particle.png" )) ) )
 
         {
 		tex = convertToGLFormat(buf);  // flipped 32bit RGBA
@@ -412,7 +412,7 @@ void Gravity::buildParticle(int loop)
 	{{1.0f,0.5f,0.5f},{1.0f,0.75f,0.5f},{1.0f,1.0f,0.5f},{0.75f,1.0f,0.5f},
 	{0.5f,1.0f,0.5f},{0.5f,1.0f,0.75f},{0.5f,1.0f,1.0f},{0.5f,0.75f,1.0f},
 	{0.5f,0.5f,1.0f},{0.75f,0.5f,1.0f},{1.0f,0.5f,1.0f},{1.0f,0.5f,0.75f}};
-	col = ( ++col ) % 12;
+	col = ( col + 1 ) % 12;
 	particle[loop].active=true;
 	particle[loop].index=KRandom::random()%100;
 	particle[loop].indexo=particle[loop].index;
